@@ -180,7 +180,11 @@ gst_plugin_load_plugin (GstPlugin *plugin, GError **error)
   module = g_module_open (filename, G_MODULE_BIND_LAZY);
 
   if (module != NULL) {
-    if (g_module_symbol (module, "plugin_desc", (gpointer *)&desc)) {
+    gpointer ptr;
+
+    if (g_module_symbol (module, "plugin_desc", &ptr)) {
+      desc = (GstPluginDesc *)ptr;
+
       GST_DEBUG (GST_CAT_PLUGIN_LOADING, "plugin \"%s\" loaded, called entry function...", filename);
 
       plugin->filename = g_strdup (filename);
@@ -361,10 +365,13 @@ gst_plugin_is_loaded (GstPlugin *plugin)
 GstPluginFeature*
 gst_plugin_find_feature (GstPlugin *plugin, const gchar *name, GType type)
 {
-  GList *features = plugin->features;
-
+  GList *features;
+  
+  g_return_val_if_fail (plugin != NULL, NULL);
   g_return_val_if_fail (name != NULL, NULL);
 
+  features = plugin->features;
+
   while (features) {
     GstPluginFeature *feature = GST_PLUGIN_FEATURE (features->data);
 
