@@ -1,4 +1,4 @@
-/* A Bison parser, made from grammar.y
+/* A Bison parser, made from ./grammar.y
    by GNU bison 1.35.  */
 
 #define YYBISON 1  /* Identify Bison output.  */
@@ -11,16 +11,17 @@
 #define yydebug _gst_parse__yydebug
 #define yynerrs _gst_parse__yynerrs
 # define	IDENTIFIER	257
-# define	CONNECTION	258
-# define	BCONNECTION	259
-# define	FCONNECTION	260
+# define	LINK	258
+# define	BLINK	259
+# define	FLINK	260
 # define	VALUE	261
 
-#line 1 "grammar.y"
+#line 1 "./grammar.y"
 
 #include <glib.h>
 #include <stdio.h>
 #include <string.h>
+#include <stdlib.h>
 #include "../gstparse.h"
 #include "types.h"
 
@@ -31,13 +32,13 @@
 static int yylex (void *lvalp);
 static int yyerror (const char *s);
 
-#line 16 "grammar.y"
+#line 17 "./grammar.y"
 #ifndef YYSTYPE
 typedef union {
     gchar *s;
     GValue *v;
     graph_t *g;
-    connection_t *c;
+    link_t *c;
     property_t *p;
     element_t *e;
 } yystype;
@@ -110,8 +111,8 @@ static const short yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined. */
 static const short yyrline[] =
 {
-       0,    45,    48,    51,    54,    58,    59,    74,    91,    98,
-     108,   109,   112,   113,   116,   117,   118,   119
+       0,    46,    49,    52,    55,    59,    60,    75,    92,    99,
+     109,   110,   113,   114,   117,   118,   119,   120
 };
 #endif
 
@@ -121,10 +122,9 @@ static const short yyrline[] =
 /* YYTNAME[TOKEN_NUM] -- String name of the token TOKEN_NUM. */
 static const char *const yytname[] =
 {
-  "$", "error", "$undefined.", "IDENTIFIER", "CONNECTION", "BCONNECTION", 
-  "FCONNECTION", "VALUE", "'{'", "'}'", "'('", "')'", "'!'", "'='", "','", 
-  "'.'", "id", "value", "property_value", "element", "graph", "bin", 
-  "connection", "rconnection", 0
+  "$", "error", "$undefined.", "IDENTIFIER", "LINK", "BLINK", "FLINK", 
+  "VALUE", "'{'", "'}'", "'('", "')'", "'!'", "'='", "','", "'.'", "id", 
+  "value", "property_value", "element", "graph", "bin", "link", "rlink", 0
 };
 #endif
 
@@ -900,43 +900,43 @@ yyreduce:
   switch (yyn) {
 
 case 2:
-#line 48 "grammar.y"
+#line 49 "./grammar.y"
 { yyval.p = g_new0 (property_t, 1); yyval.p->value = yyvsp[0].v; ;
     break;}
 case 3:
-#line 51 "grammar.y"
+#line 52 "./grammar.y"
 { yyval.p = yyvsp[0].p; yyval.p->name = yyvsp[-2].s; ;
     break;}
 case 4:
-#line 54 "grammar.y"
+#line 55 "./grammar.y"
 { static int i = 0; yyval.e = g_new0 (element_t, 1);
                                        yyval.e->type = yyvsp[0].s; yyval.e->index = ++i; ;
     break;}
 case 5:
-#line 58 "grammar.y"
+#line 59 "./grammar.y"
 { yyval.g = g_new0 (graph_t, 1); *((graph_t**) pgraph) = yyval.g; ;
     break;}
 case 6:
-#line 59 "grammar.y"
+#line 60 "./grammar.y"
 { GList *l;
-                                       yyval.g = yyvsp[-1].g; l = yyval.g->connections_pending;
+                                       yyval.g = yyvsp[-1].g; l = yyval.g->links_pending;
                                        yyval.g->elements = g_list_append (yyval.g->elements, yyvsp[0].e);
                                        yyval.g->current = yyvsp[0].e;
                                        if (!yyval.g->first)
                                            yyval.g->first = yyval.g->current;
                                        while (l) {
-                                           ((connection_t*) l->data)->sink_index = yyval.g->current->index;
+                                           ((link_t*) l->data)->sink_index = yyval.g->current->index;
                                            l = g_list_next (l);
                                        }
-                                       if (yyval.g->connections_pending) {
-                                           g_list_free (yyval.g->connections_pending);
-                                           yyval.g->connections_pending = NULL;
+                                       if (yyval.g->links_pending) {
+                                           g_list_free (yyval.g->links_pending);
+                                           yyval.g->links_pending = NULL;
                                        }
                                      ;
     break;}
 case 7:
-#line 74 "grammar.y"
-{ GList *l; yyval.g = yyvsp[-1].g; l = yyval.g->connections_pending;
+#line 75 "./grammar.y"
+{ GList *l; yyval.g = yyvsp[-1].g; l = yyval.g->links_pending;
                                        *((graph_t**) pgraph) = yyval.g;
                                        yyval.g->bins = g_list_append (yyval.g->bins, yyvsp[0].g);
                                        yyvsp[0].g->parent = yyval.g;
@@ -944,28 +944,28 @@ case 7:
                                        if (!yyval.g->first)
                                            yyval.g->first = yyval.g->current;
                                        while (l) {
-                                           ((connection_t*) l->data)->sink_index = yyval.g->current->index;
+                                           ((link_t*) l->data)->sink_index = yyval.g->current->index;
                                            l = g_list_next (l);
                                        }
-                                       if (yyval.g->connections_pending) {
-                                           g_list_free (yyval.g->connections_pending);
-                                           yyval.g->connections_pending = NULL;
+                                       if (yyval.g->links_pending) {
+                                           g_list_free (yyval.g->links_pending);
+                                           yyval.g->links_pending = NULL;
                                        }
                                        yyval.g->current = yyvsp[0].g->current;
                                      ;
     break;}
 case 8:
-#line 91 "grammar.y"
+#line 92 "./grammar.y"
 { yyval.g = yyvsp[-1].g;
-                                       yyval.g->connections = g_list_append (yyval.g->connections, yyvsp[0].c);
+                                       yyval.g->links = g_list_append (yyval.g->links, yyvsp[0].c);
 				       if (yyval.g->current)
                                          yyvsp[0].c->src_index = yyval.g->current->index;
                                        if (!yyvsp[0].c->sink_name)
-                                           yyval.g->connections_pending = g_list_append (yyval.g->connections_pending, yyvsp[0].c);
+                                           yyval.g->links_pending = g_list_append (yyval.g->links_pending, yyvsp[0].c);
                                      ;
     break;}
 case 9:
-#line 98 "grammar.y"
+#line 99 "./grammar.y"
 { yyval.g = yyvsp[-1].g;
                                        if (!yyval.g->current) {
                                            fprintf (stderr, "error: property value assignments must be preceded by an element definition\n");
@@ -976,27 +976,27 @@ case 9:
                                      ;
     break;}
 case 10:
-#line 108 "grammar.y"
+#line 109 "./grammar.y"
 { yyval.g = yyvsp[-1].g; yyval.g->current_bin_type = "thread"; ;
     break;}
 case 11:
-#line 109 "grammar.y"
+#line 110 "./grammar.y"
 { yyval.g = yyvsp[-1].g; yyval.g->current_bin_type = yyvsp[-4].s; ;
     break;}
 case 14:
-#line 116 "grammar.y"
-{ yyval.c = g_new0 (connection_t, 1); ;
+#line 117 "./grammar.y"
+{ yyval.c = g_new0 (link_t, 1); ;
     break;}
 case 15:
-#line 117 "grammar.y"
+#line 118 "./grammar.y"
 { yyval.c = yyvsp[0].c; ;
     break;}
 case 16:
-#line 118 "grammar.y"
+#line 119 "./grammar.y"
 { yyval.c = yyvsp[0].c; ;
     break;}
 case 17:
-#line 120 "grammar.y"
+#line 121 "./grammar.y"
 { yyval.c = yyvsp[-2].c;
                                        yyval.c->src_pads = g_list_prepend (yyval.c->src_pads, yyvsp[-4].s);
                                        yyval.c->sink_pads = g_list_append (yyval.c->sink_pads, yyvsp[0].s);
@@ -1235,7 +1235,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 126 "grammar.y"
+#line 127 "./grammar.y"
 
 
 extern FILE *_gst_parse_yyin;
